@@ -17,9 +17,6 @@ SERVO_VALUES = {
     "on_center": 0,
     "on_up_right": -0.5,
     "on_right": -1,
-    "on_down_left": None,  # Not in use
-    "on_down": None,  # Not in use
-    "on_down_right": None,  # Not in use
 }
 
 
@@ -39,7 +36,7 @@ class ImmediateServo:
 
     @j.on_any
     def move_servo(self, event):
-        servo_value = SERVO_VALUES[event.name]
+        servo_value = SERVO_VALUES.get(event.name)
         if servo_value is not None:
             botafar.print(f"servo value {servo_value}")
             self.servo.value = servo_value
